@@ -38,7 +38,7 @@
 #include <kfinddialog.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
-#include <k3listviewsearchline.h>
+#include <KTreeWidgetSearchLine>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdatetime.h>
@@ -70,8 +70,9 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
     setButtonGuiItem(User3, KGuiItem(i18n("&Find"), "edit-find"));
     setDefaultButton(Close);
     showButtonSeparator(true);
+    showButton(User3, false);
 
-    QSplitter *splitter = new QSplitter(Qt::Vertical, this);
+    splitter = new QSplitter(Qt::Vertical, this);
     setMainWidget(splitter);
 
     tree = new LogTreeView(this);
@@ -88,7 +89,7 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
     list = new LogListView(partConfig, listWidget);
     listLayout->addWidget(list, 1);
 
-    K3ListViewSearchLine* searchLine = new K3ListViewSearchLine(listWidget, list);
+    KTreeWidgetSearchLine* searchLine = new KTreeWidgetSearchLine(listWidget, list);
     QLabel* searchLabel = new QLabel(i18n("S&earch:"),listWidget);
     searchLabel->setBuddy(searchLine);
     searchLayout->addWidget(searchLabel);
@@ -144,6 +145,7 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
 
         revbox[i] = new QLabel(mainWidget);
         revbox[i]->setFrameStyle(QFrame::Panel | QFrame::Sunken);
+        revbox[i]->setTextInteractionFlags(Qt::TextSelectableByMouse);
         grid->addWidget(revbox[i], 0, 1, Qt::AlignVCenter);
 
         QLabel *selectlabel = new QLabel(i18n("Select by tag:"), mainWidget);
@@ -159,6 +161,7 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
 
         authorbox[i] = new QLabel(mainWidget);
         authorbox[i]->setFrameStyle(QFrame::Panel | QFrame::Sunken);
+        authorbox[i]->setTextInteractionFlags(Qt::TextSelectableByMouse);
         grid->addWidget(authorbox[i], 1, 1);
 
         QLabel *datelabel = new QLabel(i18n("Date:"), mainWidget);
@@ -166,6 +169,7 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
 
         datebox[i] = new QLabel(mainWidget);
         datebox[i]->setFrameStyle(QFrame::Panel | QFrame::Sunken);
+        datebox[i]->setTextInteractionFlags(Qt::TextSelectableByMouse);
         grid->addWidget(datebox[i], 1, 3);
 
         QLabel *commentlabel = new QLabel(i18n("Comment/Tags:"), mainWidget);
@@ -180,9 +184,12 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
         tagsbox[i] = new KTextEdit(mainWidget);
         tagsbox[i]->setReadOnly(true);
         tagsbox[i]->setMinimumHeight(2*fm.lineSpacing()+10);
-        grid->addWidget(tagsbox[i], 2, 4);
+        grid->addWidget(tagsbox[i], 0, 4, 3, 1);
     }
 
+    // initially make the version info widget as small as possible
+    splitter->setSizes(QList<int>() << height() << 1);
+
     revbox[0]->setWhatsThis( i18n("This revision is used when you click "
                                     "Annotate.\nIt is also used as the first "
                                     "item of a Diff operation."));
@@ -201,8 +208,6 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
     connect( this, SIGNAL(user3Clicked()),
              this, SLOT(findClicked()) );
 
-    connect(this,SIGNAL(okClicked()),
-            this, SLOT(slotOk()));
     connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
     setButtonGuiItem(Ok, KGuiItem(i18nc("to view revision A", "&View A"),"document-open"));
     setButtonGuiItem(Apply, KGuiItem(i18n("Create Patch...")));
@@ -214,6 +219,8 @@ LogDialog::LogDialog(KConfig& cfg, QWidget *parent)
     tabWidget->setCurrentIndex(cg.readEntry("ShowTab", 0));
     restoreDialogSize(cg);
 
+    splitter->restoreState(cg.readEntry<QByteArray>("Splitter", QByteArray()));
+
     updateButtons();
 }
 
@@ -226,6 +233,8 @@ LogDialog::~LogDialog()
     KConfigGroup cg(&partConfig, "LogDialog");
     cg.writeEntry("ShowTab", tabWidget->currentIndex());
     saveDialogSize(cg);
+
+    cg.writeEntry("Splitter", splitter->saveState());
 }
 
 
@@ -419,6 +428,17 @@ bool LogDialog::parseCvsLog(OrgKdeCervisiaCvsserviceCvsserviceInterface* service
     return true;    // successful
 }
 
+void LogDialog::slotButtonClicked(int button)
+{
+    if ( button == KDialog::Ok )
+    {
+        // ok button (used for "view") shall not close the dialog
+        slotOk();
+        return;
+    }
+
+    KDialog::slotButtonClicked(button);
+}
 
 void LogDialog::slotOk()
 {
