@@ -32,6 +32,7 @@ class LogPlainView;
 
 class KComboBox;
 class QLabel;
+class QSplitter;
 class KTabWidget;
 class KTextEdit;
 class OrgKdeCervisiaCvsserviceCvsserviceInterface;
@@ -58,6 +59,7 @@ public:
     bool parseCvsLog(OrgKdeCervisiaCvsserviceCvsserviceInterface* service, const QString& fileName);
 
 protected slots:
+    virtual void slotButtonClicked(int button);
     void slotOk();
     void slotApply();
 
@@ -74,6 +76,7 @@ private:
     void tagSelected(LogDialogTagInfo* tag, bool rmb);
     void updateButtons();
 
+    QSplitter *splitter;
     QString filename;
     QList<Cervisia::LogInfo*> items;
     QList<LogDialogTagInfo*> tags;
